"""Python environment module."""

from dataclasses import dataclass


@dataclass
class PyEnv:
    """Python environment generic class."""

    name: str
    path: str

    def __eq__(self, item):
        return self.path == str(item)


class UserPyEnv(PyEnv):
    """User python environment."""

    scope = 'USER'


class TeamPyEnv(PyEnv):
    """Team python environment."""

    scope = 'TEAM'


class GlobalPyEnv(PyEnv):
    """Global python environment."""

    scope = 'GLOBAL'


def get_pyenv_user(username: str) -> list:
    """List of python environment available to the user."""
    return [
        # Dummy values
        UserPyEnv('base', f'/micromamba/{username}'),
        UserPyEnv('pytorch', f'/micromamba/{username}/envs/pytorch'),
    ]


def get_pyenv_team() -> list:
    """List of python environment available to the user's team."""
    return [
        # Dummy values
        TeamPyEnv(
            'nuts-workshop', '/micromamba/operator/share/nuts-workshop-team/env/envs/nuts-workshop'
        ),
    ]


def get_pyenv_global() -> list:
    """List of python environment available globally."""
    return [
        # Dummy values
        GlobalPyEnv('base', '/micromamba/operator/envs/base'),
        GlobalPyEnv('data-science', '/micromamba/operator/envs/data-science'),
    ]


def get_pyenv(username: str) -> list:
    """List of all the python environment available to a user."""
    return get_pyenv_user(username) + get_pyenv_team() + get_pyenv_global()
